Utility Types
=============

Enumerations
------------

.. autoclass:: absscpi.AbsCellFault
   :members:
   :undoc-members:

.. autoclass:: absscpi.AbsCellSenseRange
   :members:
   :undoc-members:

.. autoclass:: absscpi.AbsCellMode
   :members:
   :undoc-members:

.. autoclass:: absscpi.AbsModelStatus
   :members:
   :undoc-members:

Structures
----------

.. autoclass:: absscpi.AbsDeviceInfo
   :members:

.. autoclass:: absscpi.AbsEthernetConfig
   :members:

.. autoclass:: absscpi.AbsModelInfo
   :members:

.. autoclass:: absscpi.AbsEthernetDiscoveryResult
   :members:

.. autoclass:: absscpi.AbsSerialDiscoveryResult
   :members:

Exceptions
----------

.. autoclass:: absscpi.ScpiClientError
   :members:

